@@ -4,9 +4,8 @@ import json
 import argparse
 import re
 import shlex
-import sys
 from collections import OrderedDict
-import getopt
+import pyperclip
 
 
 def parse_content_type(content_type: str):
@@ -108,7 +107,7 @@ def prettier_tuple(the_tuple, indent=4):
 
 
 def curl_replace(curl_cmd):
-    curl_replace = [(r'\r|\n', ''), (' -XPOST', ' -X POST'),
+    curl_replace = [(r'\\\r|\\\n|\r|\n', ''), (' -XPOST', ' -X POST'),
                     (' -XGET', ' -X GET'), (' -XPUT', ' -X PUT'),
                     (' -XPATCH', ' -X PATCH'), (' -XDELETE', ' -X DELETE'),
                     (' -Xnull', '')]
@@ -206,7 +205,8 @@ def parseCurlString(filestring, output_path=''):
     output += 'print(response.text)\n\n'
     file_header = '\n'.join([
         '#' * 20, "#File Name:{}".format(output_path),
-        "#This file is generated by curl2pyreqs.", '#' * 20,
+        "#This file is generated by curl2pyreqs.",
+        "#Github: https://github.com/knightz1224/curl2pyreqs", '#' * 20,
         '#!/bin/env python3\n\n'
     ])
     output = file_header + output
@@ -218,5 +218,21 @@ def parseCurlFile(filepath):
     output_path = filepath.replace('curl', 'py')
     output = parseCurlString(curlstring, output_path)
     open(filepath.replace('curl', 'py'), 'w', encoding='utf-8').write(output)
-    print('Convertion Finished.\nPlease open {} to check the code.'.format(
-        filepath.replace('curl', 'py')))
+    return 'Convertion Finished.\nPlease open {} to check the code.'.format(
+        filepath.replace('curl', 'py'))
+
+
+def convert_main(opt, arg):
+    if opt:
+        if ('-F' in opt[0]) and arg:
+            filepath = arg[0]
+            return parseCurlFile(filepath=filepath)
+    else:
+        clip = str(pyperclip.paste())
+        if clip.find('curl ') == 0:
+            output = parseCurlString(clip)
+            pyperclip.copy(output)
+            return 'Convertion Finished.\nNow requests code is copyed in your clipboard.'
+        else:
+            return 'Please copy the curl before run.'
+    return 'Usage:\n\tCurl File Convert -- curl2pyreqs -F requests.curl\n\tClipboard Convert -- curl2pyreqs -C'
